==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/at/api.php <==
<?php
regGS("The IP address group $1 has been deleted.", "IP Adressgruppe $1 wurde gelöscht.");
regGS("IP Group $1 added for user $2", "IP Adressgruppe $1 für User $2 hinzugefügt");
regGS("User permissions for $1 changed", "Userrechte für $1 geändert");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Rubrik $1 gelöscht (Ausgabe: $2, Publikation: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Rubrik $1 hinzugefügt  (Ausgabe: $2, Publikation: $3)");
regGS("Issue $1 changed status to $2", "Status von Ausgabe $1 auf $2 gesetzt");
regGS("User type $1 deleted", "Usertyp $1 gelöscht");
regGS("User type $1 added", "Usertyp $1 hinzugefügt");
regGS("Topic $1 added to article", "Topic $1 zu artikel hinzugefügt");
regGS("Last", "Letzte");
regGS("First", "Erste");
regGS("Changed image properties of $1", "Bildeigenschaften von $1 geändert");
regGS("Article topic $1 deleted", "Artikelthema $1 gelöscht");
regGS("Article #$1 \"$2\" ($3) created.", "Artikel #$1 \"$2\" ($3) erstellt.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Artikel #$1 \"$2\" ($3) übersetzt nach \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Artikel #$1 \"$2\" ($3) kopiert nach Artikel #$3");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Status von Artikel '$1: \"$2\" von $3 auf $4 gesetzt.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Artikel #$1: \"$2\" ($3) gelöscht.");
regGS("Text", "Textzeile");
regGS("Article body", "Fließtext");
regGS("The default subscription time for $1 has been added.", "Abonomentstandardzeit für $1 wurde erfolgreich hinzugefügt");
regGS("Image $1 linked to article $2", "Bild $1 mit Artikel $2 verknüpft");
regGS("Image $1 unlinked from $2", "Bild $1 von $2 entkoppelt");
regGS("The image $1 has been added.", "Bild $1 erfolgreich hinzugefügt");
regGS("Image $1 deleted", "Bild $1 gelöscht");
regGS("Publication $1 changed", "Publikation $1 wurde geändert");
regGS("Publication $1 deleted", "Publikation $1 wurde gelöscht");
regGS("Publication $1 added", "Publikation $1 wurde hinzugefügt");
regGS("Issue $1 from publication $2 deleted", "Ausgabe $1 der Publikation $2 wurde gelöscht");
regGS("Issue $1 added in publication $2", "Ausgabe $1 zu Publikation $2 hinzugefügt");
regGS("The article type $1 has been deleted.", "Artikeltyp $1 wurde gelöscht");
regGS("The article type $1 has been added.", "Artikeltyp $1 wurde hinzugefügt");
regGS("Article type field $1 created", "Artikeltyp-Feld $1erstellt");
regGS("Article type field $1 deleted", "Artikeltyp-Feld $1 gelöscht");
regGS("Language $1 added", "Sprache $1 hinzugefügt");
regGS("Language $1 deleted", "Sprache $1 gelöscht");
regGS("Language $1 modified", "Sprache $1 modifiziert");
regGS("Country $1 added", "Land $1 hinzugefügt");
regGS("Country $1 deleted", "Land $1 gelöscht");
regGS("Country name $1 changed", "Landname $1 geändert");
regGS("The user account $1 has been deleted.", "Benutzerkonto $1 wurde gelöscht");
regGS("Password changed for $1", "Passwort für $1 geändert");
regGS("User account $1 created", "Benutzerkonto $1 erstellt");
regGS("Template $1 uploaded", "Template $1 hochgeladen");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/at/api.php <==
<?php 
regGS("Template $1 no longer exists!", "");
regGS("The file uploaded is not an image.", "");
regGS("Field $1 updated", "");
regGS("Could not delete record from the database.", "");
regGS("template path", "");
regGS("short names", "");
regGS("Unable to fetch image from remote server.", "");
regGS("The article type field $1 has been renamed to $2.", "");
regGS("The article type $1 has been renamed to $2.", "");
regGS("Article type field $1 changed", "");
regGS("Article Type $1 translation updated", "");
regGS("The IP address group $1 has been deleted.", "IP Adressgruppe $1 wurde gelöscht.");
regGS("IP Group $1 added for user $2", "IP Adressgruppe $1 für User $2 hinzugefügt");
regGS("User permissions for $1 changed", "Userrechte für $1 geändert");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "Rubrik $1 gelöscht (Ausgabe: $2, Publikation: $3)");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "Rubrik $1 hinzugefügt  (Ausgabe: $2, Publikation: $3)");
regGS("Issue $1 changed status to $2", "Status von Ausgabe $1 auf $2 gesetzt");
regGS("User type $1 deleted", "Usertyp $1 gelöscht");
regGS("User type $1 added", "Usertyp $1 hinzugefügt");
regGS("Topic $1 added to article", "Topic $1 zu artikel hinzugefügt");
regGS("Last", "Letzte");
regGS("First", "Erste");
regGS("Changed image properties of $1", "Bildeigenschaften von $1 geändert");
regGS("Article topic $1 deleted", "Artikelthema $1 gelöscht");
regGS("Article #$1 \"$2\" ($3) created.", "Artikel #$1 \"$2\" ($3) erstellt.");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "Artikel #$1 \"$2\" ($3) übersetzt nach \"$5\" ($4)");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "Artikel #$1 \"$2\" ($3) kopiert nach Artikel #$3");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "Status von Artikel '$1: \"$2\" von $3 auf $4 gesetzt.");
regGS("Article #$1: \"$2\" ($3) deleted.", "Artikel #$1: \"$2\" ($3) gelöscht.");
regGS("Single-line Text", "Textzeile");
regGS("Multi-line Text with WYSIWYG", "Fließtext");
regGS("The default subscription time for $1 has been added.", "Abonomentstandardzeit für $1 wurde erfolgreich hinzugefügt");
regGS("Image $1 linked to article $2", "Bild $1 mit Artikel $2 verknüpft");
regGS("Image $1 unlinked from $2", "Bild $1 von $2 entkoppelt");
regGS("The image $1 has been added.", "Bild $1 erfolgreich hinzugefügt");
regGS("Image $1 deleted", "Bild $1 gelöscht");
regGS("Publication $1 changed", "Publikation $1 wurde geändert");
regGS("Publication $1 deleted", "Publikation $1 wurde gelöscht");
regGS("Publication $1 added", "Publikation $1 wurde hinzugefügt");
regGS("Issue $1 from publication $2 deleted", "Ausgabe $1 der Publikation $2 wurde gelöscht");
regGS("Issue $1 added in publication $2", "Ausgabe $1 zu Publikation $2 hinzugefügt");
regGS("The article type $1 has been deleted.", "Artikeltyp $1 wurde gelöscht");
regGS("The article type $1 has been added.", "Artikeltyp $1 wurde hinzugefügt");
regGS("Article type field $1 created", "Artikeltyp-Feld $1erstellt");
regGS("Article type field $1 deleted", "Artikeltyp-Feld $1 gelöscht");
regGS("Language $1 added", "Sprache $1 hinzugefügt");
regGS("Language $1 deleted", "Sprache $1 gelöscht");
regGS("Language $1 modified", "Sprache $1 modifiziert");
regGS("Country $1 added", "Land $1 hinzugefügt");
regGS("Country $1 deleted", "Land $1 gelöscht");
regGS("Country name $1 changed", "Landname $1 geändert");
regGS("The user account $1 has been deleted.", "Benutzerkonto $1 wurde gelöscht");
regGS("Password changed for $1", "Passwort für $1 geändert");
regGS("User account $1 created", "Benutzerkonto $1 erstellt");
regGS("Template $1 uploaded", "Template $1 hochgeladen");
regGS("URL \"$1\" is invalid or is not an image.", "URL \"$1\" ist ungültig oder es ist kein Bild.");
regGS("URL \"$1\" is not an image.", "Unter URL \"$1\" ist kein Bild verfügbar.");
regGS("Topic $1 added", "Thema $1 hinzugefügt");
regGS("Topic $1 deleted", "Thema $1 gelöscht");
regGS("Topic $1 updated", "Thema $1 aktualisiert");
?>
